Struct CommandLog

pub struct CommandLog<'l, P: AsRef<Path>> { /* private fields */ }
The self-referencing struct.

Implementations

Source

impl<'l, P: AsRef<Path>> CommandLog<'l, P>

pub fn with_log_file<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow &'l CommandLogFile<P>) -> ReturnType, ) -> ReturnType

Provides an immutable reference to log_file. This method was generated because log_file is a tail field.

pub fn borrow_log_file<'this>(&'this self) -> &'this &'l CommandLogFile<P>

Provides an immutable reference to log_file. This method was generated because log_file is a tail field.

pub fn with_log_file_mut<'outer_borrow, ReturnType>( &'outer_borrow mut self, user: impl for<'this> FnOnce(&'outer_borrow mut &'l CommandLogFile<P>) -> ReturnType, ) -> ReturnType

Provides a mutable reference to log_file. This method was generated because log_file is a tail field. No borrow_log_file_mut function was generated because Rust’s borrow checker is currently unable to guarantee that such a method would be used safely.

pub fn with_contents<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow String) -> ReturnType, ) -> ReturnType

Provides limited immutable access to contents. This method was generated because the contents of contents are immutably borrowed by other fields.

pub fn borrow_contents<'this>(&'this self) -> &'this String

Provides limited immutable access to contents. This method was generated because the contents of contents are immutably borrowed by other fields.

pub fn with_head_and_rest<'outer_borrow, ReturnType>( &'outer_borrow self, user: impl for<'this> FnOnce(&'outer_borrow Option<(&'this str, &'this str, usize)>) -> ReturnType, ) -> ReturnType

Provides an immutable reference to head_and_rest. This method was generated because head_and_rest is a tail field.

pub fn borrow_head_and_rest<'this>( &'this self, ) -> &'this Option<(&'this str, &'this str, usize)>

Provides an immutable reference to head_and_rest. This method was generated because head_and_rest is a tail field.

pub fn with_head_and_rest_mut<'outer_borrow, ReturnType>( &'outer_borrow mut self, user: impl for<'this> FnOnce(&'outer_borrow mut Option<(&'this str, &'this str, usize)>) -> ReturnType, ) -> ReturnType

Provides a mutable reference to head_and_rest. This method was generated because head_and_rest is a tail field. No borrow_head_and_rest_mut function was generated because Rust’s borrow checker is currently unable to guarantee that such a method would be used safely.

Source

impl<'l, P: AsRef<Path>> CommandLog<'l, P>

pub fn path(&self) -> &Path

pub fn path_string_lossy<'s>(&'s self) -> Cow<'s, str>

pub fn parse_log_file_params( &self, ) -> Result<BenchmarkingJobParameters, ParseCommandLogError>

Parse the head (not cached)

pub fn log_contents_rest(&self) -> (&str, usize)

The part of the file contents after the head, together with the 1-based line number where it starts. If there was no head detected, just give the whole file contents.